# epath

This package provides easy and dynamic way to import parent files in Python.  

Path Sample:  
Current folder  -->  "/home/apps/user/folder1/folder2/"

```
  new_path = Path().get("/../../folder3/)
  new_path --> "/home/apps/user/folder3/)

``` 
